@@ -1,6 +1,6 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU Lesser General Public License (See COPYING for details).
-// Copyright (C) 2003-2005 Simon Goodall
+// Copyright (C) 2003 - 2006 Simon Goodall
 
 #define __glext_h_ 1
 #include "GL.h"
@@ -13,19 +13,17 @@
  * function Taken from OpenGL FAQ
  */
 
-static GLubyte *extensions = NULL;
-
-int isExtensionSupported(const char *extension) {
+int isExtensionSupported(const char *extension, const GLubyte *extensions) {
 //  const GLubyte *extensions = NULL;
   const GLubyte *start;
   GLubyte *where, *terminator;
 
   /* Extension names should not have spaces. */
   where = (GLubyte *) strchr(extension, ' ');
-  if (where || *extension == '\0')
+  if ((where != NULL) || *extension == '\0')
     return 0;
   
-  if (extensions == NULL) extensions = (GLubyte*)glGetString(GL_EXTENSIONS);
+//  if (extensions == NULL) extensions = (GLubyte*)glGetString(GL_EXTENSIONS);
   
   if (extensions == NULL) return 0;
   
@@ -38,8 +36,8 @@ int isExtensionSupported(const char *extension) {
     if (!where)
       break;
     terminator = where + strlen(extension);
-    if (where == start || *(where - 1) == ' ')
-      if (*terminator == ' ' || * terminator == '\0')
+    if (where == start || *(where - 1) == (GLubyte)' ')
+      if (*terminator == (GLubyte)' ' || *terminator == (GLubyte)'\0')
         return 1;
     start = terminator;
   }
