@@ -1,12 +1,12 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU Lesser General Public License (See COPYING for details).
-// Copyright (C) 2003-2005 Simon Goodall
+// Copyright (C) 2003 - 2006 Simon Goodall
 
 #ifndef UTILITY_H
 #define UTILITY_H 1
 
 #include "sage/header.h"
 
-SAGEAPI int isExtensionSupported(const char *);
+SAGEAPI int isExtensionSupported(const char *, const GLubyte *extensions);
 
 #endif
